@@ -4,22 +4,20 @@
 # SOAP::Lite is free software; you can redistribute it
 # and/or modify it under the same terms as Perl itself.
 #
-# $Id: TCP.pm,v 1.4 2004/11/14 19:30:50 byrnereese Exp $
+# $Id: TCP.pm 353 2010-03-17 21:08:34Z kutterma $
 #
 # ======================================================================
 
 package SOAP::Transport::TCP;
 
 use strict;
-use vars qw($VERSION);
-#$VERSION = sprintf("%d.%s", map {s/_//g; $_} q$Name:  $ =~ /-(\d+)_([\d_]+)/);
-$VERSION = $SOAP::Lite::VERSION;
+
+our $VERSION = 0.711;
 
 use URI;
 use IO::Socket;
 use IO::Select;
 use IO::SessionData;
-use SOAP::Lite;
 
 # ======================================================================
 
