@@ -4,17 +4,17 @@
 # SOAP::Lite is free software; you can redistribute it
 # and/or modify it under the same terms as Perl itself.
 #
-# $Id: POP3.pm,v 1.1.1.1 2002/11/01 14:53:58 paulclinger Exp $
+# $Id: POP3.pm 354 2010-03-18 18:29:09Z kutterma $
 #
 # ======================================================================
 
 package XMLRPC::Transport::POP3;
 
 use strict;
-use vars qw($VERSION);
-$VERSION = sprintf("%d.%s", map {s/_//g; $_} q$Name: release-0_60-public $ =~ /-(\d+)_([\d_]+)/);
 
+our $VERSION = 0.711;
 use XMLRPC::Lite;
+
 use SOAP::Transport::POP3;
 
 # ======================================================================
@@ -42,12 +42,11 @@ XMLRPC::Transport::POP3 - Server side POP3 support for XMLRPC::Lite
   my $server = XMLRPC::Transport::POP3::Server
     -> new('pop://pop.mail.server')
     # if you want to have all in one place
-    # -> new('pop://user:password@pop.mail.server') 
+    # -> new('pop://user:password@pop.mail.server')
     # or, if you have server that supports MD5 protected passwords
-    # -> new('pop://user:password;AUTH=+APOP@pop.mail.server') 
+    # -> new('pop://user:password;AUTH=+APOP@pop.mail.server')
     # specify path to My/Examples.pm here
-    -> dispatch_to('/Your/Path/To/Deployed/Modules', 'Module::Name', 'Module::method') 
-  ;
+    -> dispatch_to('/Your/Path/To/Deployed/Modules', 'Module::Name', 'Module::method');
   # you don't need to use next line if you specified your password in new()
   $server->login('user' => 'password') or die "Can't authenticate to POP3 server\n";
 
