@@ -4,18 +4,18 @@
 # SOAP::Lite is free software; you can redistribute it
 # and/or modify it under the same terms as Perl itself.
 #
-# $Id: TCP.pm,v 1.2 2004/11/14 19:30:50 byrnereese Exp $
+# $Id: TCP.pm 354 2010-03-18 18:29:09Z kutterma $
 #
 # ======================================================================
 
 package XMLRPC::Transport::TCP;
 
 use strict;
-use vars qw($VERSION);
-#$VERSION = sprintf("%d.%s", map {s/_//g; $_} q$Name:  $ =~ /-(\d+)_([\d_]+)/);
-$VERSION = $XMLPRC::Lite::VERSION;
 
+our $VERSION = 0.711;
 use XMLRPC::Lite;
+
+
 use SOAP::Transport::TCP;
 
 # ======================================================================
@@ -43,8 +43,7 @@ XMLRPC::Transport::TCP - Server/Client side TCP support for XMLRPC::Lite
   my $daemon = XMLRPC::Transport::TCP::Server
     -> new (LocalAddr => 'localhost', LocalPort => 82, Listen => 5, Reuse => 1)
     -> objects_by_reference(qw(My::PersistentIterator My::SessionIterator My::Chat))
-    -> dispatch_to('/Your/Path/To/Deployed/Modules', 'Module::Name', 'Module::method') 
-  ;
+    -> dispatch_to('/Your/Path/To/Deployed/Modules', 'Module::Name', 'Module::method');
   print "Contact to XMLRPC server at ", join(':', $daemon->sockhost, $daemon->sockport), "\n";
   $daemon->handle;
 
